# UnderlineMark


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from src.client.generated.models.underline_mark import UnderlineMark

# TODO update the JSON string below
json = "{}"
# create an instance of UnderlineMark from a JSON string
underline_mark_instance = UnderlineMark.from_json(json)
# print the JSON string representation of the object
print(UnderlineMark.to_json())

# convert the object into a dict
underline_mark_dict = underline_mark_instance.to_dict()
# create an instance of UnderlineMark from a dict
underline_mark_from_dict = UnderlineMark.from_dict(underline_mark_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


